use bytemuck::{Pod, Zeroable};
use std::mem;
use wgpu;

#[repr(C)]
#[derive(Debug, Copy, Clone, Pod, Zeroable, Default)]
pub struct ImageLocation {
	/// Format: [x, y, w, h], in texture coordinates
	pub x: f32,
	pub y: f32,
	pub w: f32,
	pub h: f32,
}

#[derive(Debug, Copy, Clone)]
pub struct ImageLocations {
	/// Format: [x, y, w, h], in texture coordinates
	pub data: [ImageLocation; 108],
}

unsafe impl Pod for ImageLocations {}
unsafe impl Zeroable for ImageLocations {
	fn zeroed() -> Self {
		Self {
			data: [ImageLocation::zeroed(); 108],
		}
	}
}

impl Default for ImageLocations {
	fn default() -> Self {
		Self::zeroed()
	}
}

#[repr(C)]
#[derive(Debug, Copy, Clone, Default, Pod, Zeroable)]
pub struct AtlasContent {
	pub locations: ImageLocations,
}

impl AtlasContent {
	pub const SIZE: u64 = mem::size_of::<Self>() as wgpu::BufferAddress;
}
